@@ -882,7 +882,7 @@ class ParaMonteSampler:
     ################################################################################################################################
 
     def _setDelimiterToRead(self, delimiter, fileType, fileSuffix):
-        if self.spec.outputFileName is None:
+        if self.spec.outputDelimiter is None:
             delimiter   = ","
             if self.reportEnabled:
                 pm.warn ( msg   = "The ``delimiter`` is neither given as input to ``read" + fileType.capitalize() + "()``" + newline
@@ -1037,13 +1037,13 @@ class ParaMonteSampler:
             if fileSuffix=="progress":
                 specials = ""
             else:
-                specials =  ( "    " + outputListFullName + "[0].plot.line3()        # to make trivariate line plots." + newline
-                            + "    " + outputListFullName + "[0].plot.scatter3()     # to make trivariate scatter plots." + newline
-                            + "    " + outputListFullName + "[0].plot.lineScatter3() # to make trivariate line-scatter plots." + newline
+                specials =  ( "    " + outputListFullName + "[0].plot.line3()        # to make 3D line plots." + newline
+                            + "    " + outputListFullName + "[0].plot.scatter3()     # to make 3D scatter plots." + newline
+                            + "    " + outputListFullName + "[0].plot.lineScatter3() # to make 3D line-scatter plots." + newline
                             + "    " + outputListFullName + "[0].plot.contour()      # to make fast 2D kernel density plots." + newline
                             + "    " + outputListFullName + "[0].plot.contourf()     # to make fast 2D kernel density filled contour plots." + newline
                             + "    " + outputListFullName + "[0].plot.contour3()     # to make fast 3D kernel density contour plots." + newline
-                            + "    " + outputListFullName + "[0].plot.distplot()     # to make seaborn 1D distribution plots." + newline
+                            + "    " + outputListFullName + "[0].plot.histplot()     # to make seaborn 1D distribution plots." + newline
                             + "    " + outputListFullName + "[0].plot.kdeplot1()     # to make seaborn 1D kernel density plots." + newline
                             + "    " + outputListFullName + "[0].plot.kdeplot2()     # to make seaborn 2D kernel density plots." + newline
                             + "    " + outputListFullName + "[0].plot.grid()         # to make GridPlot" + newline
@@ -1060,9 +1060,9 @@ class ParaMonteSampler:
                             + newline
                             + "For example," + newline
                             + newline
-                            + "    " + outputListFullName + "[0].plot.line()         # to make bivariate line plots." + newline
-                            + "    " + outputListFullName + "[0].plot.scatter()      # to make bivariate scatter plots." + newline
-                            + "    " + outputListFullName + "[0].plot.lineScatter()  # to make bivariate line-scatter plots." + newline
+                            + "    " + outputListFullName + "[0].plot.line()         # to make 2D line plots." + newline
+                            + "    " + outputListFullName + "[0].plot.scatter()      # to make 2D scatter plots." + newline
+                            + "    " + outputListFullName + "[0].plot.lineScatter()  # to make 2D line-scatter plots." + newline
                             + specials
                             + newline
                             + "To plot or inspect the variable autocorrelations or the correlation/covariance matrices, try:" + newline
